@@ -302,12 +302,12 @@ def build(branch, ngBuild='', ngApp='', angularBuild='', angularEnv='', installP
 
     # ensure yarn installs all build tools
         local("pwd")
-        local('yarn --production=false --no-progress --non-interactive install --cache-folder %s' % yarn_cache)
+        local('YARN_CACHE_FOLDER %s yarn --production=false --no-progress --non-interactive install' % yarn_cache)
 
  
         if ngBuild:
             options = ' --configuration=%s ' % angularEnv if angularEnv else ''
-            local('yarn build %s %s --cache-folder %s' % (options, ngApp, yarn_cache))
+            local('YARN_CACHE_FOLDER %s yarn build %s %s' % (yarne_cache, options, ngApp))
             local('cp {package.json,yarn.lock,knexfile.js} dist/')
             local('cp -R migrations/ dist/migrations')
             local('if [ -d "apps/%s/config" ]; then cp -R "apps/%s/config" "dist/apps/%s/"; fi' % (ngApp,ngApp,ngApp))
@@ -323,11 +323,11 @@ def build(branch, ngBuild='', ngApp='', angularBuild='', angularEnv='', installP
 
 
     # make sure the new files are part of the local git repo
-    local('find . -path ./\.git -prune -o -name \.gitignore -type f -exec rm -f {} \;')
-    local('echo "%s.tar.*" >> .gitignore' % TAR_NAME)
-    local('echo "fabfile.*" >> .gitignore')
-    local("git add .")
-    local("git commit -am 'add results of build' --no-verify --quiet")
+    #local('find . -path ./\.git -prune -o -name \.gitignore -type f -exec rm -f {} \;')
+    #local('echo "%s.tar.*" >> .gitignore' % TAR_NAME)
+    #local('echo "fabfile.*" >> .gitignore')
+    #local("git add .")
+    #local("git commit -am 'add results of build' --no-verify --quiet")
 
 
 @task
